fetch_footers

Function fetch_footers 

async fn fetch_footers(
    io: &dyn WalObjectIo,
    objects: Vec<ListedObject>,
    concurrency: usize,
) -> Result<Vec<FetchedObject>>
Fetches and verifies the headers and footers of objects, up to concurrency objects at a time, and returns them ordered by object sequence whatever the order the fetches complete in. The first failure abandons the remaining fetches.