finish_recovery

Function finish_recovery 

fn finish_recovery(objects: Vec<FetchedObject>) -> Result<Recovered>
Indexes the chain of objects, which are ordered by sequence. Objects off the chain are orphans: they are not indexed, but no later object takes their sequences.