is_transient

Function is_transient 

fn is_transient(error: &Error) -> bool
Returns true for a storage error that a later attempt may not meet: one the object store reports as temporary, or as persistent, which is how its retry layer reports a temporary error that outlasted its retries.