fn is_transient(error: &Error) -> boolExpand description
Returns true for a storage error that a later attempt may not meet: one the object store reports as temporary, or as persistent, which is how its retry layer reports a temporary error that outlasted its retries.