fn locate_footer(
object_seq: u64,
object_len: usize,
head: &[u8],
tail: &[u8],
) -> Result<(Header, FixedTrailer, Range<usize>)>Expand description
Verifies the header and trailer of the object object_seq of object_len
bytes from its first bytes head and its last bytes tail, and returns
the header and the trailer with the range the footer occupies in the object.